@@ -1,5 +1,5 @@
 package Device::Firewall::PaloAlto::API;
-$Device::Firewall::PaloAlto::API::VERSION = '0.1.3';
+$Device::Firewall::PaloAlto::API::VERSION = '0.1.4';
 use strict;
 use warnings;
 use 5.010;
@@ -7,11 +7,13 @@ use 5.010;
 use URI;
 use Carp;
 use LWP::UserAgent;
-use HTTP::Request;
+use HTTP::Request::Common;
 use XML::Twig;
 use Class::Error;
 use Hook::LexWrap;
 
+use Device::Firewall::PaloAlto::Errors qw(ERROR);
+
 # VERSION
 # PODNAME
 # ABSTRACT: Palo Alto firewall API module
@@ -46,6 +48,7 @@ sub new {
     $object{uri} = $uri;
     $object{user_agent} = LWP::UserAgent->new(ssl_opts => $ssl_opts);
     $object{api_key} = '';
+    $object{vsys_id} = 1;
 
     return bless \%object, $class;
 }
@@ -102,14 +105,12 @@ sub _send_request {
     # If we're authenticated, add the API key
     $query{key} = $self->{api_key} if $self->{api_key};
 
-    # Build the URI query section
-    my $uri = $self->{uri};
-    $uri->query_form( \%query );
-
-    # Create and send the HTTP::Request
-    my $http_request = HTTP::Request->new(GET => $uri->as_string);
-    my $response = $self->_send_raw_request($http_request);
-
+    # Create the request and pass it to the raw request function.
+    # This function exists to allow us to wrap it in debug functions
+    # and see the raw requests and responses
+    my $request = POST $self->{uri}->as_string, [ %query ];
+    my $response = $self->_send_raw_request($request);
+    
     # Check and return
     return _parse_and_check_response( $response );
 }
@@ -180,22 +181,6 @@ sub _debug_post_wrap {
 }
 
 
-sub ERROR {
-    my ($errstring, $errno) = @_;
-    
-    # Are we in a one liner? If so, we croak out straight away
-    my ($sub, $file, $inc);
-    while (!defined $sub or $sub ne 'main') { 
-        ($sub, $file) = caller(++$inc);
-    } 
-    
-    croak $errstring if $file eq '-e';
-
-    return Class::Error->new($errstring, $errno);
-}
-
-
-
 
 1;
 
@@ -211,7 +196,7 @@ Device::Firewall::PaloAlto::API - Palo Alto firewall API module
 
 =head1 VERSION
 
-version 0.1.3
+version 0.1.4
 
 =head1 DESCRIPTION
 
